return <<'END';
0000	001f	Cc
0020		Zs
0021	0023	Po
0024		Sc
0025	0027	Po
0028		Ps
0029		Pe
002a		Po
002b		Sm
002c		Po
002d		Pd
002e	002f	Po
0030	0039	Nd
003a	003b	Po
003c	003e	Sm
003f	0040	Po
0041	005a	Lu
005b		Ps
005c		Po
005d		Pe
005e		Sk
005f		Pc
0060		Sk
0061	007a	Ll
007b		Ps
007c		Sm
007d		Pe
007e		Sm
007f	009f	Cc
00a0		Zs
00a1		Po
00a2	00a5	Sc
00a6	00a7	So
00a8		Sk
00a9		So
00aa		Ll
00ab		Ps
00ac		Sm
00ad		Pd
00ae		So
00af		Sk
00b0		So
00b1		Sm
00b2	00b3	No
00b4		Sk
00b5		Ll
00b6		So
00b7		Po
00b8		Sk
00b9		No
00ba		Ll
00bb		Pe
00bc	00be	No
00bf		Po
00c0	00d6	Lu
00d7		Sm
00d8	00de	Lu
00df	00f6	Ll
00f7		Sm
00f8	00ff	Ll
0100		Lu
0101		Ll
0102		Lu
0103		Ll
0104		Lu
0105		Ll
0106		Lu
0107		Ll
0108		Lu
0109		Ll
010a		Lu
010b		Ll
010c		Lu
010d		Ll
010e		Lu
010f		Ll
0110		Lu
0111		Ll
0112		Lu
0113		Ll
0114		Lu
0115		Ll
0116		Lu
0117		Ll
0118		Lu
0119		Ll
011a		Lu
011b		Ll
011c		Lu
011d		Ll
011e		Lu
011f		Ll
0120		Lu
0121		Ll
0122		Lu
0123		Ll
0124		Lu
0125		Ll
0126		Lu
0127		Ll
0128		Lu
0129		Ll
012a		Lu
012b		Ll
012c		Lu
012d		Ll
012e		Lu
012f		Ll
0130		Lu
0131		Ll
0132		Lu
0133		Ll
0134		Lu
0135		Ll
0136		Lu
0137	0138	Ll
0139		Lu
013a		Ll
013b		Lu
013c		Ll
013d		Lu
013e		Ll
013f		Lu
0140		Ll
0141		Lu
0142		Ll
0143		Lu
0144		Ll
0145		Lu
0146		Ll
0147		Lu
0148	0149	Ll
014a		Lu
014b		Ll
014c		Lu
014d		Ll
014e		Lu
014f		Ll
0150		Lu
0151		Ll
0152		Lu
0153		Ll
0154		Lu
0155		Ll
0156		Lu
0157		Ll
0158		Lu
0159		Ll
015a		Lu
015b		Ll
015c		Lu
015d		Ll
015e		Lu
015f		Ll
0160		Lu
0161		Ll
0162		Lu
0163		Ll
0164		Lu
0165		Ll
0166		Lu
0167		Ll
0168		Lu
0169		Ll
016a		Lu
016b		Ll
016c		Lu
016d		Ll
016e		Lu
016f		Ll
0170		Lu
0171		Ll
0172		Lu
0173		Ll
0174		Lu
0175		Ll
0176		Lu
0177		Ll
0178	0179	Lu
017a		Ll
017b		Lu
017c		Ll
017d		Lu
017e	0180	Ll
0181	0182	Lu
0183		Ll
0184		Lu
0185		Ll
0186	0187	Lu
0188		Ll
0189	018b	Lu
018c	018d	Ll
018e	0191	Lu
0192		Ll
0193	0194	Lu
0195		Ll
0196	0198	Lu
0199	019b	Ll
019c	019d	Lu
019e		Ll
019f	01a0	Lu
01a1		Ll
01a2		Lu
01a3		Ll
01a4		Lu
01a5		Ll
01a6	01a7	Lu
01a8		Ll
01a9		Lu
01aa		Lo
01ab		Ll
01ac		Lu
01ad		Ll
01ae	01af	Lu
01b0		Ll
01b1	01b3	Lu
01b4		Ll
01b5		Lu
01b6		Ll
01b7	01b8	Lu
01b9	01ba	Ll
01bb		Lo
01bc		Lu
01bd		Ll
01be	01c3	Lo
01c4		Lu
01c5		Lt
01c6		Ll
01c7		Lu
01c8		Lt
01c9		Ll
01ca		Lu
01cb		Lt
01cc		Ll
01cd		Lu
01ce		Ll
01cf		Lu
01d0		Ll
01d1		Lu
01d2		Ll
01d3		Lu
01d4		Ll
01d5		Lu
01d6		Ll
01d7		Lu
01d8		Ll
01d9		Lu
01da		Ll
01db		Lu
01dc	01dd	Ll
01de		Lu
01df		Ll
01e0		Lu
01e1		Ll
01e2		Lu
01e3		Ll
01e4		Lu
01e5		Ll
01e6		Lu
01e7		Ll
01e8		Lu
01e9		Ll
01ea		Lu
01eb		Ll
01ec		Lu
01ed		Ll
01ee		Lu
01ef	01f0	Ll
01f1		Lu
01f2		Lt
01f3		Ll
01f4		Lu
01f5		Ll
01fa		Lu
01fb		Ll
01fc		Lu
01fd		Ll
01fe		Lu
01ff		Ll
0200		Lu
0201		Ll
0202		Lu
0203		Ll
0204		Lu
0205		Ll
0206		Lu
0207		Ll
0208		Lu
0209		Ll
020a		Lu
020b		Ll
020c		Lu
020d		Ll
020e		Lu
020f		Ll
0210		Lu
0211		Ll
0212		Lu
0213		Ll
0214		Lu
0215		Ll
0216		Lu
0217		Ll
0250	02a8	Ll
02b0	02b8	Lm
02b9	02ba	Sk
02bb	02c1	Lm
02c2	02cf	Sk
02d0	02d1	Lm
02d2	02de	Sk
02e0	02e4	Lm
02e5	02e9	Sk
0300	0345	Mn
0360	0361	Mn
0374	0375	Po
037a		Lm
037e		Po
0384	0385	Sk
0386		Lu
0387		Po
0388	038a	Lu
038c		Lu
038e	038f	Lu
0390		Ll
0391	03a1	Lu
03a3	03ab	Lu
03ac	03ce	Ll
03d0	03d1	Ll
03d2	03d4	Lu
03d5	03d6	Ll
03da		Lu
03dc		Lu
03de		Lu
03e0		Lu
03e2		Lu
03e3		Ll
03e4		Lu
03e5		Ll
03e6		Lu
03e7		Ll
03e8		Lu
03e9		Ll
03ea		Lu
03eb		Ll
03ec		Lu
03ed		Ll
03ee		Lu
03ef	03f2	Ll
03f3		Lo
0401	040c	Lu
040e	042f	Lu
0430	044f	Ll
0451	045c	Ll
045e	045f	Ll
0460		Lu
0461		Ll
0462		Lu
0463		Ll
0464		Lu
0465		Ll
0466		Lu
0467		Ll
0468		Lu
0469		Ll
046a		Lu
046b		Ll
046c		Lu
046d		Ll
046e		Lu
046f		Ll
0470		Lu
0471		Ll
0472		Lu
0473		Ll
0474		Lu
0475		Ll
0476		Lu
0477		Ll
0478		Lu
0479		Ll
047a		Lu
047b		Ll
047c		Lu
047d		Ll
047e		Lu
047f		Ll
0480		Lu
0481		Ll
0482		So
0483	0486	Mn
0490		Lu
0491		Ll
0492		Lu
0493		Ll
0494		Lu
0495		Ll
0496		Lu
0497		Ll
0498		Lu
0499		Ll
049a		Lu
049b		Ll
049c		Lu
049d		Ll
049e		Lu
049f		Ll
04a0		Lu
04a1		Ll
04a2		Lu
04a3		Ll
04a4		Lu
04a5		Ll
04a6		Lu
04a7		Ll
04a8		Lu
04a9		Ll
04aa		Lu
04ab		Ll
04ac		Lu
04ad		Ll
04ae		Lu
04af		Ll
04b0		Lu
04b1		Ll
04b2		Lu
04b3		Ll
04b4		Lu
04b5		Ll
04b6		Lu
04b7		Ll
04b8		Lu
04b9		Ll
04ba		Lu
04bb		Ll
04bc		Lu
04bd		Ll
04be		Lu
04bf		Ll
04c0		Lo
04c1		Lu
04c2		Ll
04c3		Lu
04c4		Ll
04c7		Lu
04c8		Ll
04cb		Lu
04cc		Ll
04d0		Lu
04d1		Ll
04d2		Lu
04d3		Ll
04d4		Lu
04d5		Ll
04d6		Lu
04d7		Ll
04d8		Lu
04d9		Ll
04da		Lu
04db		Ll
04dc		Lu
04dd		Ll
04de		Lu
04df		Ll
04e0		Lu
04e1		Ll
04e2		Lu
04e3		Ll
04e4		Lu
04e5		Ll
04e6		Lu
04e7		Ll
04e8		Lu
04e9		Ll
04ea		Lu
04eb		Ll
04ee		Lu
04ef		Ll
04f0		Lu
04f1		Ll
04f2		Lu
04f3		Ll
04f4		Lu
04f5		Ll
04f8		Lu
04f9		Ll
0531	0556	Lu
0559		Lm
055a	055f	Po
0561	0587	Ll
0589		Po
0591	05a1	Mn
05a3	05b9	Mn
05bb	05bd	Mn
05be		Po
05bf		Mn
05c0		Po
05c1	05c2	Mn
05c3		Po
05c4		Mn
05d0	05ea	Lo
05f0	05f2	Lo
05f3	05f4	Po
060c		Po
061b		Po
061f		Po
0621	063a	Lo
0640		Lm
0641	064a	Lo
064b	0652	Mn
0660	0669	Nd
066a	066d	Po
0670		Mn
0671	06b7	Lo
06ba	06be	Lo
06c0	06ce	Lo
06d0	06d3	Lo
06d4		Po
06d5		Lo
06d6	06dc	Mn
06dd	06de	Me
06df	06e4	Mn
06e5	06e6	Lm
06e7	06e8	Mn
06e9		So
06ea	06ed	Mn
06f0	06f9	Nd
0901	0902	Mn
0903		Mc
0905	0939	Lo
093c		Mn
093d		Lo
093e	0940	Mc
0941	0948	Mn
0949	094c	Mc
094d		Mn
0950		So
0951	0954	Mn
0958	0961	Lo
0962	0963	Mn
0964	0965	Po
0966	096f	Nd
0970		Po
0981		Mn
0982	0983	Mc
0985	098c	Lo
098f	0990	Lo
0993	09a8	Lo
09aa	09b0	Lo
09b2		Lo
09b6	09b9	Lo
09bc		Mn
09be	09c0	Mc
09c1	09c4	Mn
09c7	09c8	Mc
09cb	09cc	Mc
09cd		Mn
09d7		Mc
09dc	09dd	Lo
09df	09e1	Lo
09e2	09e3	Mn
09e6	09ef	Nd
09f0	09f1	Lo
09f2	09f3	Sc
09f4	09f9	No
09fa		So
0a02		Mn
0a05	0a0a	Lo
0a0f	0a10	Lo
0a13	0a28	Lo
0a2a	0a30	Lo
0a32	0a33	Lo
0a35	0a36	Lo
0a38	0a39	Lo
0a3c		Mn
0a3e	0a40	Mc
0a41	0a42	Mn
0a47	0a48	Mn
0a4b	0a4d	Mn
0a59	0a5c	Lo
0a5e		Lo
0a66	0a6f	Nd
0a70	0a71	Mn
0a72	0a74	Lo
0a81	0a82	Mn
0a83		Mc
0a85	0a8b	Lo
0a8d		Lo
0a8f	0a91	Lo
0a93	0aa8	Lo
0aaa	0ab0	Lo
0ab2	0ab3	Lo
0ab5	0ab9	Lo
0abc		Mn
0abd		Lo
0abe	0ac0	Mc
0ac1	0ac5	Mn
0ac7	0ac8	Mn
0ac9		Mc
0acb	0acc	Mc
0acd		Mn
0ad0		So
0ae0		Lo
0ae6	0aef	Nd
0b01		Mn
0b02	0b03	Mc
0b05	0b0c	Lo
0b0f	0b10	Lo
0b13	0b28	Lo
0b2a	0b30	Lo
0b32	0b33	Lo
0b36	0b39	Lo
0b3c		Mn
0b3d		Lo
0b3e		Mc
0b3f		Mn
0b40		Mc
0b41	0b43	Mn
0b47	0b48	Mc
0b4b	0b4c	Mc
0b4d		Mn
0b56		Mn
0b57		Mc
0b5c	0b5d	Lo
0b5f	0b61	Lo
0b66	0b6f	Nd
0b70		So
0b82		Mn
0b83		Mc
0b85	0b8a	Lo
0b8e	0b90	Lo
0b92	0b95	Lo
0b99	0b9a	Lo
0b9c		Lo
0b9e	0b9f	Lo
0ba3	0ba4	Lo
0ba8	0baa	Lo
0bae	0bb5	Lo
0bb7	0bb9	Lo
0bbe	0bbf	Mc
0bc0		Mn
0bc1	0bc2	Mc
0bc6	0bc8	Mc
0bca	0bcc	Mc
0bcd		Mn
0bd7		Mc
0be7	0bef	Nd
0bf0	0bf2	No
0c01	0c03	Mc
0c05	0c0c	Lo
0c0e	0c10	Lo
0c12	0c28	Lo
0c2a	0c33	Lo
0c35	0c39	Lo
0c3e	0c40	Mn
0c41	0c44	Mc
0c46	0c48	Mn
0c4a	0c4d	Mn
0c55	0c56	Mn
0c60	0c61	Lo
0c66	0c6f	Nd
0c82	0c83	Mc
0c85	0c8c	Lo
0c8e	0c90	Lo
0c92	0ca8	Lo
0caa	0cb3	Lo
0cb5	0cb9	Lo
0cbe		Mc
0cbf		Mn
0cc0	0cc4	Mc
0cc6		Mn
0cc7	0cc8	Mc
0cca	0ccb	Mc
0ccc	0ccd	Mn
0cd5	0cd6	Mc
0cde		Lo
0ce0	0ce1	Lo
0ce6	0cef	Nd
0d02	0d03	Mc
0d05	0d0c	Lo
0d0e	0d10	Lo
0d12	0d28	Lo
0d2a	0d39	Lo
0d3e	0d40	Mc
0d41	0d43	Mn
0d46	0d48	Mc
0d4a	0d4c	Mc
0d4d		Mn
0d57		Mc
0d60	0d61	Lo
0d66	0d6f	Nd
0e01	0e2e	Lo
0e2f		Po
0e30		Lo
0e31		Mn
0e32	0e33	Lo
0e34	0e3a	Mn
0e3f		Sc
0e40	0e45	Lo
0e46		Lm
0e47	0e4e	Mn
0e4f		So
0e50	0e59	Nd
0e5a	0e5b	Po
0e81	0e82	Lo
0e84		Lo
0e87	0e88	Lo
0e8a		Lo
0e8d		Lo
0e94	0e97	Lo
0e99	0e9f	Lo
0ea1	0ea3	Lo
0ea5		Lo
0ea7		Lo
0eaa	0eab	Lo
0ead	0eae	Lo
0eaf		Po
0eb0		Lo
0eb1		Mn
0eb2	0eb3	Lo
0eb4	0eb9	Mn
0ebb	0ebc	Mn
0ebd		Lo
0ec0	0ec4	Lo
0ec6		Lm
0ec8	0ecd	Mn
0ed0	0ed9	Nd
0edc	0edd	Lo
0f00	0f03	So
0f04	0f12	Po
0f13	0f17	So
0f18	0f19	Mn
0f1a	0f1f	So
0f20	0f29	Nd
0f2a	0f33	No
0f34		So
0f35		Mn
0f36		So
0f37		Mn
0f38		So
0f39		Mn
0f3a		Ps
0f3b		Pe
0f3c		Ps
0f3d		Pe
0f3e	0f3f	Mc
0f40	0f47	Lo
0f49	0f69	Lo
0f71	0f7e	Mn
0f7f		Mc
0f80	0f84	Mn
0f85		Po
0f86	0f8b	Mn
0f90	0f95	Mn
0f97		Mn
0f99	0fad	Mn
0fb1	0fb7	Mn
0fb9		Mn
10a0	10c5	Lu
10d0	10f6	Ll
10fb		Po
1100	1159	Lo
115f	11a2	Lo
11a8	11f9	Lo
1200	135a	Lo
1361	1368	Po
1369	1371	Nd
1372	137c	No
1e00		Lu
1e01		Ll
1e02		Lu
1e03		Ll
1e04		Lu
1e05		Ll
1e06		Lu
1e07		Ll
1e08		Lu
1e09		Ll
1e0a		Lu
1e0b		Ll
1e0c		Lu
1e0d		Ll
1e0e		Lu
1e0f		Ll
1e10		Lu
1e11		Ll
1e12		Lu
1e13		Ll
1e14		Lu
1e15		Ll
1e16		Lu
1e17		Ll
1e18		Lu
1e19		Ll
1e1a		Lu
1e1b		Ll
1e1c		Lu
1e1d		Ll
1e1e		Lu
1e1f		Ll
1e20		Lu
1e21		Ll
1e22		Lu
1e23		Ll
1e24		Lu
1e25		Ll
1e26		Lu
1e27		Ll
1e28		Lu
1e29		Ll
1e2a		Lu
1e2b		Ll
1e2c		Lu
1e2d		Ll
1e2e		Lu
1e2f		Ll
1e30		Lu
1e31		Ll
1e32		Lu
1e33		Ll
1e34		Lu
1e35		Ll
1e36		Lu
1e37		Ll
1e38		Lu
1e39		Ll
1e3a		Lu
1e3b		Ll
1e3c		Lu
1e3d		Ll
1e3e		Lu
1e3f		Ll
1e40		Lu
1e41		Ll
1e42		Lu
1e43		Ll
1e44		Lu
1e45		Ll
1e46		Lu
1e47		Ll
1e48		Lu
1e49		Ll
1e4a		Lu
1e4b		Ll
1e4c		Lu
1e4d		Ll
1e4e		Lu
1e4f		Ll
1e50		Lu
1e51		Ll
1e52		Lu
1e53		Ll
1e54		Lu
1e55		Ll
1e56		Lu
1e57		Ll
1e58		Lu
1e59		Ll
1e5a		Lu
1e5b		Ll
1e5c		Lu
1e5d		Ll
1e5e		Lu
1e5f		Ll
1e60		Lu
1e61		Ll
1e62		Lu
1e63		Ll
1e64		Lu
1e65		Ll
1e66		Lu
1e67		Ll
1e68		Lu
1e69		Ll
1e6a		Lu
1e6b		Ll
1e6c		Lu
1e6d		Ll
1e6e		Lu
1e6f		Ll
1e70		Lu
1e71		Ll
1e72		Lu
1e73		Ll
1e74		Lu
1e75		Ll
1e76		Lu
1e77		Ll
1e78		Lu
1e79		Ll
1e7a		Lu
1e7b		Ll
1e7c		Lu
1e7d		Ll
1e7e		Lu
1e7f		Ll
1e80		Lu
1e81		Ll
1e82		Lu
1e83		Ll
1e84		Lu
1e85		Ll
1e86		Lu
1e87		Ll
1e88		Lu
1e89		Ll
1e8a		Lu
1e8b		Ll
1e8c		Lu
1e8d		Ll
1e8e		Lu
1e8f		Ll
1e90		Lu
1e91		Ll
1e92		Lu
1e93		Ll
1e94		Lu
1e95	1e9b	Ll
1ea0		Lu
1ea1		Ll
1ea2		Lu
1ea3		Ll
1ea4		Lu
1ea5		Ll
1ea6		Lu
1ea7		Ll
1ea8		Lu
1ea9		Ll
1eaa		Lu
1eab		Ll
1eac		Lu
1ead		Ll
1eae		Lu
1eaf		Ll
1eb0		Lu
1eb1		Ll
1eb2		Lu
1eb3		Ll
1eb4		Lu
1eb5		Ll
1eb6		Lu
1eb7		Ll
1eb8		Lu
1eb9		Ll
1eba		Lu
1ebb		Ll
1ebc		Lu
1ebd		Ll
1ebe		Lu
1ebf		Ll
1ec0		Lu
1ec1		Ll
1ec2		Lu
1ec3		Ll
1ec4		Lu
1ec5		Ll
1ec6		Lu
1ec7		Ll
1ec8		Lu
1ec9		Ll
1eca		Lu
1ecb		Ll
1ecc		Lu
1ecd		Ll
1ece		Lu
1ecf		Ll
1ed0		Lu
1ed1		Ll
1ed2		Lu
1ed3		Ll
1ed4		Lu
1ed5		Ll
1ed6		Lu
1ed7		Ll
1ed8		Lu
1ed9		Ll
1eda		Lu
1edb		Ll
1edc		Lu
1edd		Ll
1ede		Lu
1edf		Ll
1ee0		Lu
1ee1		Ll
1ee2		Lu
1ee3		Ll
1ee4		Lu
1ee5		Ll
1ee6		Lu
1ee7		Ll
1ee8		Lu
1ee9		Ll
1eea		Lu
1eeb		Ll
1eec		Lu
1eed		Ll
1eee		Lu
1eef		Ll
1ef0		Lu
1ef1		Ll
1ef2		Lu
1ef3		Ll
1ef4		Lu
1ef5		Ll
1ef6		Lu
1ef7		Ll
1ef8		Lu
1ef9		Ll
1f00	1f07	Ll
1f08	1f0f	Lu
1f10	1f15	Ll
1f18	1f1d	Lu
1f20	1f27	Ll
1f28	1f2f	Lu
1f30	1f37	Ll
1f38	1f3f	Lu
1f40	1f45	Ll
1f48	1f4d	Lu
1f50	1f57	Ll
1f59		Lu
1f5b		Lu
1f5d		Lu
1f5f		Lu
1f60	1f67	Ll
1f68	1f6f	Lu
1f70	1f7d	Ll
1f80	1f87	Ll
1f88	1f8f	Lu
1f90	1f97	Ll
1f98	1f9f	Lu
1fa0	1fa7	Ll
1fa8	1faf	Lu
1fb0	1fb4	Ll
1fb6	1fb7	Ll
1fb8	1fbc	Lu
1fbd		Sk
1fbe		Lu
1fbf	1fc1	Sk
1fc2	1fc4	Ll
1fc6	1fc7	Ll
1fc8	1fcc	Lu
1fcd	1fcf	Sk
1fd0	1fd3	Ll
1fd6	1fd7	Ll
1fd8	1fdb	Lu
1fdd	1fdf	Sk
1fe0	1fe7	Ll
1fe8	1fec	Lu
1fed	1fef	Sk
1ff2	1ff4	Ll
1ff6	1ff7	Ll
1ff8	1ffc	Lu
1ffd	1ffe	Sk
2000	200b	Zs
200c	200f	Cf
2010	2015	Pd
2016	2017	Po
2018		Ps
2019		Pe
201a	201c	Ps
201d		Pe
201e	201f	Ps
2020	2027	Po
2028		Zl
2029		Zp
202a	202e	Cf
2030	2038	Po
2039		Ps
203a		Pe
203b	203e	Po
203f	2040	Pc
2041	2043	Po
2044		Sm
2045		Ps
2046		Pe
206a	206f	Cf
2070		No
2074	2079	No
207a	207c	Sm
207d		Ps
207e		Pe
207f		Ll
2080	2089	No
208a	208c	Sm
208d		Ps
208e		Pe
20a0	20ac	Sc
20d0	20dc	Mn
20dd	20e0	Me
20e1		Mn
2100	2101	So
2102		Lu
2103	2106	So
2107		Lu
2108	2109	So
210a		Ll
210b	210d	Lu
210e	210f	Ll
2110	2112	Lu
2113		Ll
2114		So
2115		Lu
2116	2117	So
2118	211d	Lu
211e	2123	So
2124		Lu
2125		So
2126		Lu
2127		So
2128		Lu
2129		So
212a	212d	Lu
212e	212f	Ll
2130	2131	Lu
2132		So
2133		Lu
2134		Ll
2135	2138	Lo
2153	215f	No
2160	2182	Nl
2190	2194	Sm
2195	21d1	So
21d2		Sm
21d3		So
21d4		Sm
21d5	21ea	So
2200	22f1	Sm
2300		So
2302	2307	So
2308	230b	Sm
230c	231f	So
2320	2321	Sm
2322	2328	So
2329		Ps
232a		Pe
232b	237a	So
2400	2424	So
2440	244a	So
2460	249b	No
249c	24e9	So
24ea		No
2500	2595	So
25a0	25ef	So
2600	2613	So
261a	266f	So
2701	2704	So
2706	2709	So
270c	2727	So
2729	274b	So
274d		So
274f	2752	So
2756		So
2758	275e	So
2761	2767	So
2776	2793	No
2794		So
2798	27af	So
27b1	27be	So
3000		Zs
3001	3003	Po
3004		So
3005		Lm
3006		Po
3007		Nl
3008		Ps
3009		Pe
300a		Ps
300b		Pe
300c		Ps
300d		Pe
300e		Ps
300f		Pe
3010		Ps
3011		Pe
3012	3013	So
3014		Ps
3015		Pe
3016		Ps
3017		Pe
3018		Ps
3019		Pe
301a		Ps
301b		Pe
301c		Pd
301d		Ps
301e	301f	Pe
3020		So
3021	3029	Nl
302a	302f	Mn
3030		Pd
3031	3035	Lm
3036	3037	So
303f		So
3041	3094	Lo
3099	309a	Mn
309b	309e	Lm
30a1	30fa	Lo
30fb		Po
30fc	30fe	Lm
3105	312c	Lo
3131	318e	Lo
3190	3191	So
3192	3195	No
3196	319f	So
3200	321c	So
3220	3229	No
322a	3243	So
3260	327b	So
327f		So
3280	3289	No
328a	32b0	So
32c0	32cb	So
32d0	32fe	So
3300	3376	So
337b	33dd	So
33e0	33fe	So
4e00	9fa5	Lo
ac00	d7a3	Lo
d800	db7f	Cs
db80	dbff	Cs
dc00	dfff	Cs
e000	f8ff	Co
f900	fa2d	Lo
fb00	fb06	Ll
fb13	fb17	Ll
fb1e		Mn
fb1f	fb28	Lo
fb29		Sm
fb2a	fb36	Lo
fb38	fb3c	Lo
fb3e		Lo
fb40	fb41	Lo
fb43	fb44	Lo
fb46	fbb1	Lo
fbd3	fd3d	Lo
fd3e		Ps
fd3f		Pe
fd50	fd8f	Lo
fd92	fdc7	Lo
fdf0	fdfb	Lo
fe20	fe23	Mn
fe30		Po
fe31	fe32	Pd
fe33	fe34	Pc
fe35		Ps
fe36		Pe
fe37		Ps
fe38		Pe
fe39		Ps
fe3a		Pe
fe3b		Ps
fe3c		Pe
fe3d		Ps
fe3e		Pe
fe3f		Ps
fe40		Pe
fe41		Ps
fe42		Pe
fe43		Ps
fe44		Pe
fe49	fe4c	Po
fe4d	fe4f	Pc
fe50	fe52	Po
fe54	fe57	Po
fe58		Pd
fe59		Ps
fe5a		Pe
fe5b		Ps
fe5c		Pe
fe5d		Ps
fe5e		Pe
fe5f	fe61	Po
fe62		Sm
fe63		Pd
fe64	fe66	Sm
fe68		Po
fe69		Sc
fe6a	fe6b	Po
fe70	fe72	Lo
fe74		Lo
fe76	fefc	Lo
feff		Cf
ff01	ff03	Po
ff04		Sc
ff05	ff07	Po
ff08		Ps
ff09		Pe
ff0a		Po
ff0b		Sm
ff0c		Po
ff0d		Pd
ff0e	ff0f	Po
ff10	ff19	Nd
ff1a	ff1b	Po
ff1c	ff1e	Sm
ff1f	ff20	Po
ff21	ff3a	Lu
ff3b		Ps
ff3c		Po
ff3d		Pe
ff3e		Sk
ff3f		Pc
ff40		Sk
ff41	ff5a	Ll
ff5b		Ps
ff5c		Sm
ff5d		Pe
ff5e		Sm
ff61		Po
ff62		Ps
ff63		Pe
ff64	ff65	Po
ff66	ff6f	Lo
ff70		Lm
ff71	ff9d	Lo
ff9e	ff9f	Lm
ffa0	ffbe	Lo
ffc2	ffc7	Lo
ffca	ffcf	Lo
ffd2	ffd7	Lo
ffda	ffdc	Lo
ffe0	ffe1	Sc
ffe2		Sm
ffe3		Sk
ffe4		So
ffe5	ffe6	Sc
ffe8	ffec	Sm
ffed	ffee	So
fffc	fffd	So
END
